@@ -53,12 +53,13 @@ public slots:
     void setAutoRotation();
     void setSmartReflex();
     void showHelp();
-    //void showLoadPresetDialog();
     void showSettings();
+    void showTemporaryMaxFreq();
 
 
 private:
     Ui::MainWindow *ui;
+    void calculateMinFreq();
     int callHelper( QString action, QString param );
     QString getCPUTemp();
     int getMaxFreq();
@@ -72,8 +73,6 @@ private:
     QProcess helperProcess;
     //! The help window
     HelpWindow helpWindow;
-    //! Initializes the application
-    void init();
     LoadPreset *loadPresetDialog;
     int minFreq;
     QString readSysFile( QString sys_file );
