@@ -38,6 +38,7 @@ Settings::Settings(QWidget *parent) :
 
     //read values from config file
     autoRotate = settings.value("main/autorotate", true).toBool();
+    confirmApply = settings.value("main/confirm_apply", true).toBool();
     overclocking = settings.value("main/overclocking", false).toBool();
     advancedTemperature = settings.value("main/advanced_temperature", false).toBool();
 
@@ -122,6 +123,7 @@ bool Settings::platformMaemo()
 void Settings::reset()
 {
     ui->checkBox_rotate->setChecked(autoRotate);
+    ui->checkBox_confirmapply->setChecked(confirmApply);
     ui->checkBox_oc->setChecked(overclocking);
     ui->checkBox_temperature->setChecked(advancedTemperature);
 }
@@ -135,10 +137,12 @@ void Settings::reset()
 void Settings::save()
 {
     autoRotate = ui->checkBox_rotate->isChecked();
+    confirmApply = ui->checkBox_confirmapply->isChecked();
     overclocking = ui->checkBox_oc->isChecked();
     advancedTemperature = ui->checkBox_temperature->isChecked();
 
     settings.setValue("main/autorotate", autoRotate);
+    settings.setValue("main/confirm_apply", confirmApply);
     settings.setValue("main/overclocking", overclocking);
     settings.setValue("main/advanced_temperature", advancedTemperature);
 
@@ -176,6 +180,16 @@ bool Settings::useAdvancedTemperature()
 }
 
 
+/**
+  * Do we need to display a confirmation dialog before applying new
+  * frequencies?
+  */
+bool Settings::useConfirmation()
+{
+    return confirmApply;
+}
+
+
 /**
   * Returns true if auto-Rotate is enabled.
   */
